@@ -1,8 +1,10 @@
 package App::bif::Build;
-$App::bif::Build::VERSION = '0.1.0_15';
-$App::bif::Build::COMMIT = '3e3df501b25e150f2775d3ebde5cbb223b568372';
+use strict;
+use warnings;
+$App::bif::Build::VERSION = '0.1.0_16';
+$App::bif::Build::COMMIT = '88540b04e4f061e0231487d2411b3daaa6ce95b8';
 $App::bif::Build::BRANCH = 'devel';
-$App::bif::Build::DATE = '2014-04-25 14:17:39';
+$App::bif::Build::DATE = '2014-05-01 13:26:53';
 1;
 __END__
 
@@ -12,7 +14,7 @@ App::bif::Build - build-time constants for App-bif
 
 =head1 VERSION
 
-0.1.0_15 (2014-04-25)
+0.1.0_16 (2014-05-01)
 
 =head1 SYNOPSIS
 
@@ -41,16 +43,16 @@ follows:
 The Git branch name which was current when the App-bif distribution was
 created.
 
-=item $App::bif::Build::COMMIT = "3e3df501b25e150f2775d3ebde5cbb223b568372"
+=item $App::bif::Build::COMMIT = "88540b04e4f061e0231487d2411b3daaa6ce95b8"
 
 The Git commit hash at the head of the branch when the App-bif
 distribution was created.
 
-=item $App::bif::Build::DATE = "2014-04-25 14:17:39"
+=item $App::bif::Build::DATE = "2014-05-01 13:26:53"
 
 The UTC date that the Makefile.PL file was run.
 
-=item $App::bif::Build::VERSION = "0.1.0_15"
+=item $App::bif::Build::VERSION = "0.1.0_16"
 
 The version of the App-bif distribution.
 
